#=========================================================================#
#                             betaFD-comment                              #
#=========================================================================#

# Comment on:
# Patrick, C. J., and B. L. Brown. 2018. Species pool functional diversity 
# plays a hidden role in generating beta-diversity. The American Naturalist
# 191: E159-E170.

# Author: David Stoker (dstoker92@gmail.com)
# Last Updated: 30 April 2018

## Table of Contents
# Line  23: Load Packages and Data
# Line  58: Data Management
# Line  87: Structural Equation Modeling
# Line 132: SEMs: Original Models
# Line 454: SEMs: Alternative Models
# Line 707: End of Script


#=========================================================================#
#                          Load Packages and Data                         #
#==========================================================================
library(AICcmodavg)
library(lavaan)

## Set woring directory
setwd("~/Documents/Research/betaFD-comment")

## Read in provided data (downloaded 19 March 2018)
provided.data <- read.csv("patrick_brown_2017-data.csv")

## Metadata provided with the dryad citation:
# Data accompanying the analyses in Patrick & Brown 2017, Species pool 
# functional diversity plays a hidden role in generating β-diversity. Eight 
# columns by 266 rows. Each row corresponds to a community type in a particular 
# watershed. Community type is designated by the "group" column (P = Predator, 
# H = Herbivore, F = Filterer, C = Collector-Gatherer, S = Shredder, 
# all = Whole Community). Watershed is denoted in the "MDE8Digit" column by 
# a code referring to a Maryland 8 Digit watershed code (corresponds to USGS HUC12).
# The average within stream alpha richness for the watershed is in the "alpha" 
# column. The total gamma richness for the watershed is in the "gamma" column.
# The functional diversity, expressed as RaoQ, for the species pool of the 
# watershed is in the "fdiv" column. The beta diversity, expressed as mean 
# bray curtis dissimilarity, of the watershed is in the "bdiv" column. The 
# environmental dispersion, expressed as multivariate dispersion among 
# environmental variables, is in the "envdisp" column. Please see Patrick &
# Brown 2017 for detailed methods.

## Citation for data:
# Patrick, C. J., and B. L. Brown. 2018. Data from: Species pool functional
# diversity plays a hidden role in generating beta-diversity. American Naturalist,
# Dryad Digital Repository, http://dx.doi.org/10.5061/dryad.5n0c3.


#=========================================================================#
#                             Data Management                             #
#==========================================================================

## Subset data by community type
full.community.data.bin.1 <- provided.data[provided.data$group == "All", -2]
collector.data.bin.1      <- provided.data[provided.data$group == "C", -2]
herbivore.data.bin.1      <- provided.data[provided.data$group == "H", -2]
filterer.data.bin.1       <- provided.data[provided.data$group == "F", -2]
shredder.data.bin.1       <- provided.data[provided.data$group == "S", -2]
predator.data.bin.1       <- provided.data[provided.data$group == "P", -2]

## Remove "group" column as the identifier is no longer required
full.community.data.bin.2 <- full.community.data.bin.1[, -1] # "FULL"
collector.data.bin.2      <- collector.data.bin.1[, -1] # "CG"
herbivore.data.bin.2      <- herbivore.data.bin.1[, -1] # "SC"
filterer.data.bin.2       <- filterer.data.bin.1[, -1] # "FF"
shredder.data.bin.2       <- shredder.data.bin.1[, -1] # "SH"
predator.data.bin.2       <- predator.data.bin.1[, -1] # "PR"

## Center and scale data prior to path analyses
full.community.data <- as.data.frame(scale(full.community.data.bin.2, center = TRUE, scale = TRUE))
collector.data      <- as.data.frame(scale(collector.data.bin.2, center = TRUE, scale = TRUE))
herbivore.data      <- as.data.frame(scale(herbivore.data.bin.2, center = TRUE, scale = TRUE))
filterer.data       <- as.data.frame(scale(filterer.data.bin.2, center = TRUE, scale = TRUE))
shredder.data       <- as.data.frame(scale(shredder.data.bin.2, center = TRUE, scale = TRUE))
predator.data       <- as.data.frame(scale(predator.data.bin.2, center = TRUE, scale = TRUE))


#=========================================================================#
#                       Structural Equation Modeling                      #
#==========================================================================


## Structural equation models (SEMs) were constructed to evaluate the causal 
## pathways through which environmental variation, functional diversity, and 
## gamma diversity affect beta diversity. Structural equation modes are 
## tests of fit to the data, not significant pathways within the SEM (Grace 
## 2006). Model fit was assessed by comparing expected and observed covariance
## between predictor and response variables using chi-square tests (Grace 2006).
## Structural equation models were considered consistent with the data when
## expected and observed covariance was not significantly different. 
## Hypothesized (and for the second model set, alternative hypotheses in SEM 
## form) SEMs were then compared using Akaike’s information criterion (AIC, 
## Burnham and Anderson 2002), deltaAIC (change in AIC value; a threshold of
## 2 was used to determine if models were equivalent, Burnham and 
## Anderson 2002), and AICweight (relative support for the model, Burnham 
## and Anderson 2002, Grace 2006). All SEMs were estimated by maximum likelihood.
## Model results are reported as standardized path coefficients, which show 
## the direction and magnitude of the causal relationship between variables 
## and allow for the comparison of relationship strengths within the SEM 
## (Grace 2006). All data were scaled (i.e. centered on the mean and then 
## divided by the standard deviation) prior to analysis. Scaling was done
## on the full dataset and then on each functional feeding group subset individually.

## For an in-depth decription of SEM, please see:
# Grace, J. B. 2006. Structural equation modeling and natural systems. 
# Cambridge University Press, Cambridge, United Kingdom.

# Grace, J. B., T. M. Anderson, H. Olff, and S. M. Scheiner. 2010. On the 
# specification of structural equation models for ecological systems. 
# Ecological Monographs 80:67-87.

## For an in-depth description of AIC, please see:
# Burnham, K. P., and D. R. Anderson. 2002. Model selection and multi-model
# inference: a practical information-theoretic approach. Second edition. 
# Springer, New York, New York, USA.


#=========================================================================#
#                             Original Models                             #
#==========================================================================


## List of SEMs defined in Patrick & Brown 2018
SEM.1 <- "fdiv ~ gamma
          bdiv ~ gamma + fdiv + envdisp"

SEM.2 <- "bdiv ~ gamma + envdisp
          fdiv ~~ gamma"

SEM.3 <- "bdiv ~ gamma + fdiv + envdisp
          fdiv ~~ gamma"

SEM.4 <- "bdiv ~ fdiv + envdisp
          fdiv ~~ gamma"

SEM.5 <- "fdiv ~ gamma
          bdiv ~ fdiv + envdisp"


#--------------------------------------------------------------------------
#                            Full Community                               #
#-------------------------------------------------------------------------#

## Hypothesized SEM 1
FULL.SEM.1.fit <- sem(SEM.1, data = full.community.data, fixed.x = FALSE, 
								      estimator = "ML")
FULL.SEM.1.fit
summary(FULL.SEM.1.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.1.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 2
FULL.SEM.2.fit <- sem(SEM.2, data = full.community.data, fixed.x = FALSE, 
								      estimator = "ML")
FULL.SEM.2.fit
summary(FULL.SEM.2.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.2.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 3
FULL.SEM.3.fit <- sem(SEM.3, data = full.community.data, fixed.x = FALSE, 
								      estimator = "ML")
FULL.SEM.3.fit
summary(FULL.SEM.3.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.3.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 4
FULL.SEM.4.fit <- sem(SEM.4, data = full.community.data, fixed.x = FALSE, 
								      estimator = "ML")
FULL.SEM.4.fit
summary(FULL.SEM.4.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.4.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 5
FULL.SEM.5.fit <- sem(SEM.5, data = full.community.data, fixed.x = FALSE, 
								      estimator = "ML")
FULL.SEM.5.fit
summary(FULL.SEM.5.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.5.fit, type = "std.all") # Get path coefficients

## List of candidate models
FULL.SEM.list <- list(FULL.SEM.1.fit, FULL.SEM.2.fit, FULL.SEM.3.fit,
											FULL.SEM.4.fit, FULL.SEM.5.fit)

## Get AIC, delta.AIC, and model weights
FULL.SEM.AIC.table <- aictab(FULL.SEM.list, 
														 modnames = c("Model.1", "Model.2", "Model.3",
														 						  "Model.4", "Model.5"),
														 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                         Collector Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 1
CG.SEM.1.fit <- sem(SEM.1, data = collector.data, fixed.x = FALSE, 
											estimator = "ML")
CG.SEM.1.fit
summary(CG.SEM.1.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.1.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 2
CG.SEM.2.fit <- sem(SEM.2, data = collector.data, fixed.x = FALSE, 
											estimator = "ML")
CG.SEM.2.fit
summary(CG.SEM.2.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.2.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 3
CG.SEM.3.fit <- sem(SEM.3, data = collector.data, fixed.x = FALSE, 
											estimator = "ML")
CG.SEM.3.fit
summary(CG.SEM.3.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.3.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 4
CG.SEM.4.fit <- sem(SEM.4, data = collector.data, fixed.x = FALSE, 
											estimator = "ML")
CG.SEM.4.fit
summary(CG.SEM.4.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.4.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 5
CG.SEM.5.fit <- sem(SEM.5, data = collector.data, fixed.x = FALSE, 
											estimator = "ML")
CG.SEM.5.fit
summary(CG.SEM.5.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.5.fit, type = "std.all") # Get path coefficients

## List of candidate models
CG.SEM.list <- list(CG.SEM.1.fit, CG.SEM.2.fit, CG.SEM.3.fit,
									  CG.SEM.4.fit, CG.SEM.5.fit)

## Get AIC, delta.AIC, and model weights
CG.SEM.AIC.table <- aictab(CG.SEM.list, 
													 modnames = c("Model.1", "Model.2", "Model.3",
														 						"Model.4", "Model.5"),
													 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                         Herbivore Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 1
SC.SEM.1.fit <- sem(SEM.1, data = herbivore.data, fixed.x = FALSE, 
										estimator = "ML")
SC.SEM.1.fit
summary(SC.SEM.1.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.1.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 2
SC.SEM.2.fit <- sem(SEM.2, data = herbivore.data, fixed.x = FALSE, 
										estimator = "ML")
SC.SEM.2.fit
summary(SC.SEM.2.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.2.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 3
SC.SEM.3.fit <- sem(SEM.3, data = herbivore.data, fixed.x = FALSE, 
										estimator = "ML")
SC.SEM.3.fit
summary(SC.SEM.3.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.3.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 4
SC.SEM.4.fit <- sem(SEM.4, data = herbivore.data, fixed.x = FALSE, 
										estimator = "ML")
SC.SEM.4.fit # Poor model fit, hypothesis is not supported!
summary(SC.SEM.4.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.4.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 5
SC.SEM.5.fit <- sem(SEM.5, data = herbivore.data, fixed.x = FALSE, 
										estimator = "ML")
SC.SEM.5.fit # Poor model fit, hypothesis is not supported!
summary(SC.SEM.5.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.5.fit, type = "std.all") # Get path coefficients

## List of candidate models
SC.SEM.list <- list(SC.SEM.1.fit, SC.SEM.2.fit, SC.SEM.3.fit,
										SC.SEM.4.fit, SC.SEM.5.fit)

## Get AIC, delta.AIC, and model weights
SC.SEM.AIC.table <- aictab(SC.SEM.list, 
													 modnames = c("Model.1", "Model.2", "Model.3",
													 						  "Model.4", "Model.5"),
													 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                          Filterer Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 1
FF.SEM.1.fit <- sem(SEM.1, data = filterer.data, fixed.x = FALSE, 
										estimator = "ML")
FF.SEM.1.fit
summary(FF.SEM.1.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.1.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 2
FF.SEM.2.fit <- sem(SEM.2, data = filterer.data, fixed.x = FALSE, 
										estimator = "ML")
FF.SEM.2.fit # Poor model fit, hypothesis is not supported!
summary(FF.SEM.2.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.2.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 3
FF.SEM.3.fit <- sem(SEM.3, data = filterer.data, fixed.x = FALSE, 
										estimator = "ML")
FF.SEM.3.fit
summary(FF.SEM.3.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.3.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 4
FF.SEM.4.fit <- sem(SEM.4, data = filterer.data, fixed.x = FALSE, 
										estimator = "ML")
FF.SEM.4.fit 
summary(FF.SEM.4.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.4.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 5
FF.SEM.5.fit <- sem(SEM.5, data = filterer.data, fixed.x = FALSE, 
										estimator = "ML")
FF.SEM.5.fit 
summary(FF.SEM.5.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.5.fit, type = "std.all") # Get path coefficients

## List of candidate models
FF.SEM.list <- list(FF.SEM.1.fit, FF.SEM.2.fit, FF.SEM.3.fit,
										FF.SEM.4.fit, FF.SEM.5.fit)

## Get AIC, delta.AIC, and model weights
FF.SEM.AIC.table <- aictab(FF.SEM.list, 
													 modnames = c("Model.1", "Model.2", "Model.3",
													 						  "Model.4", "Model.5"),
													 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                          Shredder Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 1
SH.SEM.1.fit <- sem(SEM.1, data = shredder.data, fixed.x = FALSE, 
										estimator = "ML")
SH.SEM.1.fit
summary(SH.SEM.1.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.1.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 2
SH.SEM.2.fit <- sem(SEM.2, data = shredder.data, fixed.x = FALSE, 
										estimator = "ML")
SH.SEM.2.fit
summary(SH.SEM.2.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.2.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 3
SH.SEM.3.fit <- sem(SEM.3, data = shredder.data, fixed.x = FALSE, 
										estimator = "ML")
SH.SEM.3.fit
summary(SH.SEM.3.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.3.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 4
SH.SEM.4.fit <- sem(SEM.4, data = shredder.data, fixed.x = FALSE, 
										estimator = "ML")
SH.SEM.4.fit # Poor model fit, hypothesis is not supported!
summary(SH.SEM.4.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.4.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 5
SH.SEM.5.fit <- sem(SEM.5, data = shredder.data, fixed.x = FALSE, 
										estimator = "ML")
SH.SEM.5.fit # Poor model fit, hypothesis is not supported!
summary(SH.SEM.5.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.5.fit, type = "std.all") # Get path coefficients

## List of candidate models
SH.SEM.list <- list(SH.SEM.1.fit, SH.SEM.2.fit, SH.SEM.3.fit,
										SH.SEM.4.fit, SH.SEM.5.fit)

## Get AIC, delta.AIC, and model weights
SH.SEM.AIC.table <- aictab(SH.SEM.list, 
													 modnames = c("Model.1", "Model.2", "Model.3",
													 						  "Model.4", "Model.5"),
													 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                          Predator Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 1
PR.SEM.1.fit <- sem(SEM.1, data = predator.data, fixed.x = FALSE, 
										estimator = "ML")
PR.SEM.1.fit
summary(PR.SEM.1.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.1.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 2
PR.SEM.2.fit <- sem(SEM.2, data = predator.data, fixed.x = FALSE, 
										estimator = "ML")
PR.SEM.2.fit
summary(PR.SEM.2.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.2.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 3
PR.SEM.3.fit <- sem(SEM.3, data = predator.data, fixed.x = FALSE, 
										estimator = "ML")
PR.SEM.3.fit
summary(PR.SEM.3.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.3.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 4
PR.SEM.4.fit <- sem(SEM.4, data = predator.data, fixed.x = FALSE, 
										estimator = "ML")
PR.SEM.4.fit # Poor model fit, hypothesis is not supported!
summary(PR.SEM.4.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.4.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 5
PR.SEM.5.fit <- sem(SEM.5, data = predator.data, fixed.x = FALSE, 
										estimator = "ML")
PR.SEM.5.fit # Poor model fit, hypothesis is not supported!
summary(PR.SEM.5.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.5.fit, type = "std.all") # Get path coefficients

## List of candidate models
PR.SEM.list <- list(PR.SEM.1.fit, PR.SEM.2.fit, PR.SEM.3.fit,
										PR.SEM.4.fit, PR.SEM.5.fit)

## Get AIC, delta.AIC, and model weights
PR.SEM.AIC.table <- aictab(PR.SEM.list, 
													 modnames = c("Model.1", "Model.2", "Model.3",
													 						  "Model.4", "Model.5"),
													 second.ord = FALSE, sort = TRUE)


#=========================================================================#
#                           Alternative Models                            #
#==========================================================================


## List of SEMs defined in the re-analysis and subsequent comment paper:
SEM.6 <- "fdiv ~ gamma
          bdiv ~ gamma + envdisp"

SEM.7 <- "fdiv ~ gamma
          bdiv ~ gamma + envdisp
          bdiv ~~ fdiv"

SEM.8 <- "bdiv ~ envdisp
          fdiv ~~ bdiv
          fdiv ~~ gamma
          bdiv ~~ gamma"


#--------------------------------------------------------------------------
#                            Full Community                               #
#-------------------------------------------------------------------------#

## Hypothesized SEM 6
FULL.SEM.6.fit <- sem(SEM.6, data = full.community.data, fixed.x = FALSE, 
											estimator = "ML")
FULL.SEM.6.fit
summary(FULL.SEM.6.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.6.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 7
FULL.SEM.7.fit <- sem(SEM.7, data = full.community.data, fixed.x = FALSE, 
											estimator = "ML")
FULL.SEM.7.fit
summary(FULL.SEM.7.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.7.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 8
FULL.SEM.8.fit <- sem(SEM.8, data = full.community.data, fixed.x = FALSE, 
											estimator = "ML")
FULL.SEM.8.fit
summary(FULL.SEM.8.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FULL.SEM.8.fit, type = "std.all") # Get path coefficients


## List of candidate models
FULL.SEM.list.2 <- list(FULL.SEM.1.fit, FULL.SEM.2.fit, FULL.SEM.3.fit,
												FULL.SEM.4.fit, FULL.SEM.5.fit, FULL.SEM.6.fit,
												FULL.SEM.7.fit, FULL.SEM.8.fit)

## Get AIC, delta.AIC, and model weights
FULL.SEM.AIC.table.2 <- aictab(FULL.SEM.list.2, 
															 modnames = c("Model.1", "Model.2", "Model.3",
															 						  "Model.4", "Model.5", "Model.6",
															 						  "Model.7", "Model.8"),
															 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                         Collector Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 6
CG.SEM.6.fit <- sem(SEM.6, data = collector.data, fixed.x = FALSE, 
										estimator = "ML")
CG.SEM.6.fit
summary(CG.SEM.6.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.6.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 7
CG.SEM.7.fit <- sem(SEM.7, data = collector.data, fixed.x = FALSE, 
										estimator = "ML")
CG.SEM.7.fit
summary(CG.SEM.7.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.7.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 8
CG.SEM.8.fit <- sem(SEM.8, data = collector.data, fixed.x = FALSE, 
										estimator = "ML")
CG.SEM.8.fit
summary(CG.SEM.8.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(CG.SEM.8.fit, type = "std.all") # Get path coefficients


## List of candidate models
CG.SEM.list.2 <- list(CG.SEM.1.fit, CG.SEM.2.fit, CG.SEM.3.fit,
											CG.SEM.4.fit, CG.SEM.5.fit, CG.SEM.6.fit,
											CG.SEM.7.fit, CG.SEM.8.fit)

## Get AIC, delta.AIC, and model weights
CG.SEM.AIC.table.2 <- aictab(CG.SEM.list.2, 
														 modnames = c("Model.1", "Model.2", "Model.3",
														 						  "Model.4", "Model.5", "Model.6",
														 						  "Model.7", "Model.8"),
														 second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                         Herbivore Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 6
SC.SEM.6.fit <- sem(SEM.6, data = herbivore.data, fixed.x = FALSE, 
                    estimator = "ML")
SC.SEM.6.fit
summary(SC.SEM.6.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.6.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 7
SC.SEM.7.fit <- sem(SEM.7, data = herbivore.data, fixed.x = FALSE, 
                    estimator = "ML")
SC.SEM.7.fit
summary(SC.SEM.7.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.7.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 8
SC.SEM.8.fit <- sem(SEM.8, data = herbivore.data, fixed.x = FALSE, 
                    estimator = "ML")
SC.SEM.8.fit
summary(SC.SEM.8.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SC.SEM.8.fit, type = "std.all") # Get path coefficients


## List of candidate models
SC.SEM.list.2 <- list(SC.SEM.1.fit, SC.SEM.2.fit, SC.SEM.3.fit,
                      SC.SEM.4.fit, SC.SEM.5.fit, SC.SEM.6.fit,
                      SC.SEM.7.fit, SC.SEM.8.fit)

## Get AIC, delta.AIC, and model weights
SC.SEM.AIC.table.2 <- aictab(SC.SEM.list.2, 
                             modnames = c("Model.1", "Model.2", "Model.3",
                             						  "Model.4", "Model.5", "Model.6",
                             						  "Model.7", "Model.8"),
                             second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                          Filterer Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 6
FF.SEM.6.fit <- sem(SEM.6, data = filterer.data, fixed.x = FALSE, 
                    estimator = "ML")
FF.SEM.6.fit
summary(FF.SEM.6.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.6.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 7
FF.SEM.7.fit <- sem(SEM.7, data = filterer.data, fixed.x = FALSE, 
                    estimator = "ML")
FF.SEM.7.fit
summary(FF.SEM.7.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.7.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 8
FF.SEM.8.fit <- sem(SEM.8, data = filterer.data, fixed.x = FALSE, 
                    estimator = "ML")
FF.SEM.8.fit
summary(FF.SEM.8.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(FF.SEM.8.fit, type = "std.all") # Get path coefficients


## List of candidate models
FF.SEM.list.2 <- list(FF.SEM.1.fit, FF.SEM.2.fit, FF.SEM.3.fit,
                      FF.SEM.4.fit, FF.SEM.5.fit, FF.SEM.6.fit,
                      FF.SEM.7.fit, FF.SEM.8.fit)

## Get AIC, delta.AIC, and model weights
FF.SEM.AIC.table.2 <- aictab(FF.SEM.list.2, 
                             modnames = c("Model.1", "Model.2", "Model.3",
                             						  "Model.4", "Model.5", "Model.6",
                             						  "Model.7", "Model.8"),
                             second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                          Shredder Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 6
SH.SEM.6.fit <- sem(SEM.6, data = shredder.data, fixed.x = FALSE, 
                    estimator = "ML")
SH.SEM.6.fit
summary(SH.SEM.6.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.6.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 7
SH.SEM.7.fit <- sem(SEM.7, data = shredder.data, fixed.x = FALSE, 
                    estimator = "ML")
SH.SEM.7.fit
summary(SH.SEM.7.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.7.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 8
SH.SEM.8.fit <- sem(SEM.8, data = shredder.data, fixed.x = FALSE, 
                    estimator = "ML")
SH.SEM.8.fit
summary(SH.SEM.8.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(SH.SEM.8.fit, type = "std.all") # Get path coefficients


## List of candidate models
SH.SEM.list.2 <- list(SH.SEM.1.fit, SH.SEM.2.fit, SH.SEM.3.fit,
                      SH.SEM.4.fit, SH.SEM.5.fit, SH.SEM.6.fit,
                      SH.SEM.7.fit, SH.SEM.8.fit)

## Get AIC, delta.AIC, and model weights
SH.SEM.AIC.table.2 <- aictab(SH.SEM.list.2, 
                             modnames = c("Model.1", "Model.2", "Model.3",
                             						  "Model.4", "Model.5", "Model.6",
                             						  "Model.7", "Model.8"),
                             second.ord = FALSE, sort = TRUE)


#--------------------------------------------------------------------------
#                          Predator Community                             #
#-------------------------------------------------------------------------#

## Hypothesized SEM 6
PR.SEM.6.fit <- sem(SEM.6, data = predator.data, fixed.x = FALSE, 
                    estimator = "ML")
PR.SEM.6.fit
summary(PR.SEM.6.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.6.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 7
PR.SEM.7.fit <- sem(SEM.7, data = predator.data, fixed.x = FALSE, 
                    estimator = "ML")
PR.SEM.7.fit
summary(PR.SEM.7.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.7.fit, type = "std.all") # Get path coefficients

## Hypothesized SEM 8
PR.SEM.8.fit <- sem(SEM.8, data = predator.data, fixed.x = FALSE, 
                    estimator = "ML")
PR.SEM.8.fit
summary(PR.SEM.8.fit, rsq = TRUE, standardized = TRUE, modindices = FALSE)
standardizedSolution(PR.SEM.8.fit, type = "std.all") # Get path coefficients


## List of candidate models
PR.SEM.list.2 <- list(PR.SEM.1.fit, PR.SEM.2.fit, PR.SEM.3.fit,
                      PR.SEM.4.fit, PR.SEM.5.fit, PR.SEM.6.fit,
                      PR.SEM.7.fit, PR.SEM.8.fit)

## Get AIC, delta.AIC, and model weights
PR.SEM.AIC.table.2 <- aictab(PR.SEM.list.2, 
                             modnames = c("Model.1", "Model.2", "Model.3",
                             						  "Model.4", "Model.5", "Model.6",
                             						  "Model.7", "Model.8"),
                             second.ord = FALSE, sort = TRUE)


#=========================================================================#
#                               End of script                             #
#=========================================================================#

save.image("~/Documents/Research/betaFD-comment/betaFD-comment-Workspace.RData")
